# coding: utf-8

# flake8: noqa

"""
    Wink Payment API

    A programmatic way to create bookings, receive payment and disburse funds globally.  ## APIs Not every integrator needs every APIs. For that reason, we have separated APIs into context.  - [Affiliate](/affiliate): All APIs related to selling travel inventory as an affiliate. - [Analytics](/analytics): All APIs related to tracking metrics across a wide variety of data source segments including, more entertaining, leaderboard metrics. - [Booking](/booking): All APIs related to creating platform bookings. - [Channel Manager](/channel-manager): All APIs related to channel managers who want to integrate with our platform. - [Extranet](/extranet): All APIs related to managing travel inventory and suppliers. - [Inventory](/inventory): All APIs related to retrieve known travel inventory as it was found using the Lookup API.. - [Lookup](/lookup): All APIs related to locating inventory by region, locale and property flags. - [Reference](/reference): All APIs related to retrieving platform-supported taxonomies. - [TripPay](/payment): All APIs related to TripPay account management, booking, mapping and integration features.  ## SDKs We are actively working on supporting the most used languages out there. If you don't see your language here, reach out to us with a request to officially add your language. In the meantime, if you want to roll your own SDK, you can do so by downloading the OpenAPI spec and using one of the many available OpenAPI generators available: [https://openapi-generator.tech/docs/generators](https://openapi-generator.tech/docs/generators).  - Java SDK [https://github.com/wink-travel/trip-pay-sdk-java](https://github.com/wink-travel/trip-pay-sdk-java)  # Usage These features are made available to you via a [REST API](https://en.wikipedia.org/wiki/Representational_state_transfer). This API is language agnostic. We will link to SDKs for the most popular programming languages on this page as they become available.  ## Versioning We chose to version our endpoints in a way that we hope affects your integration with us the least. You request the version of our API you wish to work with via the `Wink-Version` header. When it's time for you to upgrade, you only have to change the version number to get access to our updated endpoints.  ## Release history - Follow updates on Github: https://github.com/wink-travel/wink-sdk-java/blob/master/CHANGELOG.md 

    The version of the OpenAPI document: 30.18.1
    Contact: bjorn@wink.travel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.24"

# import apis into sdk package
from trip_pay_payment.api.account_api import AccountApi
from trip_pay_payment.api.account_mappings_api import AccountMappingsApi
from trip_pay_payment.api.activity_stream_api import ActivityStreamApi
from trip_pay_payment.api.affiliate_api import AffiliateApi
from trip_pay_payment.api.agent_api import AgentApi
from trip_pay_payment.api.application_api import ApplicationApi
from trip_pay_payment.api.contract_api import ContractApi
from trip_pay_payment.api.managing_entity_api import ManagingEntityApi
from trip_pay_payment.api.mapping_api import MappingApi
from trip_pay_payment.api.notification_api import NotificationApi
from trip_pay_payment.api.ping_api import PingApi
from trip_pay_payment.api.webhook_api import WebhookApi
from trip_pay_payment.api.send_notification_controller_api import SendNotificationControllerApi

# import ApiClient
from trip_pay_payment.api_response import ApiResponse
from trip_pay_payment.api_client import ApiClient
from trip_pay_payment.configuration import Configuration
from trip_pay_payment.exceptions import OpenApiException
from trip_pay_payment.exceptions import ApiTypeError
from trip_pay_payment.exceptions import ApiValueError
from trip_pay_payment.exceptions import ApiKeyError
from trip_pay_payment.exceptions import ApiAttributeError
from trip_pay_payment.exceptions import ApiException

# import models into sdk package
from trip_pay_payment.models.account import Account
from trip_pay_payment.models.account_status_response import AccountStatusResponse
from trip_pay_payment.models.acquirer_credentials import AcquirerCredentials
from trip_pay_payment.models.activity_stream import ActivityStream
from trip_pay_payment.models.activity_stream_user import ActivityStreamUser
from trip_pay_payment.models.address import Address
from trip_pay_payment.models.affiliate_details_request import AffiliateDetailsRequest
from trip_pay_payment.models.affiliate_information import AffiliateInformation
from trip_pay_payment.models.aggregate_booking_contract_cancellation_state import AggregateBookingContractCancellationState
from trip_pay_payment.models.aggregate_booking_contract_capture_currencies_by_account_response import AggregateBookingContractCaptureCurrenciesByAccountResponse
from trip_pay_payment.models.aggregate_descriptor import AggregateDescriptor
from trip_pay_payment.models.application import Application
from trip_pay_payment.models.authenticated_user import AuthenticatedUser
from trip_pay_payment.models.available_funds import AvailableFunds
from trip_pay_payment.models.bank_account import BankAccount
from trip_pay_payment.models.beneficiary import Beneficiary
from trip_pay_payment.models.beneficiary_aggregate_data import BeneficiaryAggregateData
from trip_pay_payment.models.beneficiary_charge import BeneficiaryCharge
from trip_pay_payment.models.booking_contract import BookingContract
from trip_pay_payment.models.booking_contract_cancellable_response import BookingContractCancellableResponse
from trip_pay_payment.models.booking_contract_grid_response import BookingContractGridResponse
from trip_pay_payment.models.booking_contract_item import BookingContractItem
from trip_pay_payment.models.booking_contract_payment_details import BookingContractPaymentDetails
from trip_pay_payment.models.cancel_booking_contract_request import CancelBookingContractRequest
from trip_pay_payment.models.composite_filter_descriptor import CompositeFilterDescriptor
from trip_pay_payment.models.contact import Contact
from trip_pay_payment.models.count_response import CountResponse
from trip_pay_payment.models.country_lightweight import CountryLightweight
from trip_pay_payment.models.create_account_request import CreateAccountRequest
from trip_pay_payment.models.create_agent_sale_request import CreateAgentSaleRequest
from trip_pay_payment.models.create_application_response import CreateApplicationResponse
from trip_pay_payment.models.create_mapping_request import CreateMappingRequest
from trip_pay_payment.models.custom_monetary_amount import CustomMonetaryAmount
from trip_pay_payment.models.external_booking_contract import ExternalBookingContract
from trip_pay_payment.models.filter_descriptor import FilterDescriptor
from trip_pay_payment.models.geo_json_point import GeoJsonPoint
from trip_pay_payment.models.geo_name_lightweight import GeoNameLightweight
from trip_pay_payment.models.group_descriptor import GroupDescriptor
from trip_pay_payment.models.guest_user import GuestUser
from trip_pay_payment.models.immediate_refund_request import ImmediateRefundRequest
from trip_pay_payment.models.integrator import Integrator
from trip_pay_payment.models.key_value_pair import KeyValuePair
from trip_pay_payment.models.managing_entity import ManagingEntity
from trip_pay_payment.models.mapping import Mapping
from trip_pay_payment.models.multi_booking_contract_response import MultiBookingContractResponse
from trip_pay_payment.models.notification import Notification
from trip_pay_payment.models.page_account import PageAccount
from trip_pay_payment.models.page_booking_contract import PageBookingContract
from trip_pay_payment.models.page_mapping import PageMapping
from trip_pay_payment.models.pageable_object import PageableObject
from trip_pay_payment.models.payable_contract import PayableContract
from trip_pay_payment.models.payable_contract_request import PayableContractRequest
from trip_pay_payment.models.payable_contract_response import PayableContractResponse
from trip_pay_payment.models.payable_contract_supplier import PayableContractSupplier
from trip_pay_payment.models.payable_contract_supplier_item import PayableContractSupplierItem
from trip_pay_payment.models.payable_contract_supplier_item_beneficiary import PayableContractSupplierItemBeneficiary
from trip_pay_payment.models.personal import Personal
from trip_pay_payment.models.preferences import Preferences
from trip_pay_payment.models.priced_supplier_contract_with_acquirer import PricedSupplierContractWithAcquirer
from trip_pay_payment.models.profile_lightweight import ProfileLightweight
from trip_pay_payment.models.profile_user import ProfileUser
from trip_pay_payment.models.quote_lightweight import QuoteLightweight
from trip_pay_payment.models.refund_request import RefundRequest
from trip_pay_payment.models.remove_entry_response import RemoveEntryResponse
from trip_pay_payment.models.revoke_client_id_response import RevokeClientIdResponse
from trip_pay_payment.models.send_notification import SendNotification
from trip_pay_payment.models.set_tax_identifier_request import SetTaxIdentifierRequest
from trip_pay_payment.models.simple_date_time_itinerary import SimpleDateTimeItinerary
from trip_pay_payment.models.sort_descriptor import SortDescriptor
from trip_pay_payment.models.sort_object import SortObject
from trip_pay_payment.models.state import State
from trip_pay_payment.models.sub_country_lightweight import SubCountryLightweight
from trip_pay_payment.models.sub_sub_country_lightweight import SubSubCountryLightweight
from trip_pay_payment.models.supplier_contract_item_policy import SupplierContractItemPolicy
from trip_pay_payment.models.total_aggregate_funds import TotalAggregateFunds
from trip_pay_payment.models.unique_result import UniqueResult
from trip_pay_payment.models.update_application_response import UpdateApplicationResponse
from trip_pay_payment.models.update_mapping_request import UpdateMappingRequest
from trip_pay_payment.models.upsert_account_mapping_request import UpsertAccountMappingRequest
from trip_pay_payment.models.upsert_account_request import UpsertAccountRequest
from trip_pay_payment.models.upsert_activity_stream_request import UpsertActivityStreamRequest
from trip_pay_payment.models.upsert_address_request import UpsertAddressRequest
from trip_pay_payment.models.upsert_application_request import UpsertApplicationRequest
from trip_pay_payment.models.upsert_bank_account_request import UpsertBankAccountRequest
from trip_pay_payment.models.upsert_city_only_address_request import UpsertCityOnlyAddressRequest
from trip_pay_payment.models.upsert_webhook_request import UpsertWebhookRequest
from trip_pay_payment.models.verify_account_request import VerifyAccountRequest
from trip_pay_payment.models.webhook import Webhook



# flake8: noqa

# import apis into api package
from trip_pay_payment.api.account_api import AccountApi
from trip_pay_payment.api.account_mappings_api import AccountMappingsApi
from trip_pay_payment.api.activity_stream_api import ActivityStreamApi
from trip_pay_payment.api.affiliate_api import AffiliateApi
from trip_pay_payment.api.agent_api import AgentApi
from trip_pay_payment.api.application_api import ApplicationApi
from trip_pay_payment.api.contract_api import ContractApi
from trip_pay_payment.api.managing_entity_api import ManagingEntityApi
from trip_pay_payment.api.mapping_api import MappingApi
from trip_pay_payment.api.notification_api import NotificationApi
from trip_pay_payment.api.ping_api import PingApi
from trip_pay_payment.api.webhook_api import WebhookApi
from trip_pay_payment.api.send_notification_controller_api import SendNotificationControllerApi

